==> sagua_0.2.0-1.tar.gz: sagua-0.2.0/src/aboutdlg.cc <==
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file aboutdlg.cc
/// @brief Class for 'About dialog' source file. 

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <libintl.h>

#include <gtkmm/box.h>
#include <gtkmm/stock.h>

#include "../include/aboutdlg.h"

AboutDlg::AboutDlg()
: logoImg_( PIXMAPSDIR "sagua-logo.png" )
{
    set_title( gettext("About") );
    set_resizable(false);
    set_border_width(12);

    Glib::ustring aboutString = "<span weight=\"bold\" size=\"xx-large\">Sagua v" \
			PACKAGE_VERSION "</span>\n\nA Music Player for Gtk+/Gnome\n\n" \
			"<span size=\"small\">Copyright (c) 2004 HG, Rhee &lt;ez8tank@krpost.net&gt;" \
			"\nunder GNU GPL2</span>";
    infoLabel_.set_label(aboutString);
    infoLabel_.set_justify(Gtk::JUSTIFY_CENTER);
    infoLabel_.set_use_markup(true);
    
    Gtk::VBox* mainBox = get_vbox();
    mainBox->set_spacing(6);
    mainBox->pack_start(logoImg_);
    mainBox->pack_start(infoLabel_); 

    Gtk::Button* okBtn = add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);
    okBtn->signal_clicked().connect(
	sigc::mem_fun(*this, &AboutDlg::OnBtnOk) );

    show_all_children();
}

AboutDlg::~AboutDlg()
{
}

/// @brief Callback function when press OK button.
///
/// Callback function when press OK button. Just close dialog.
void AboutDlg::OnBtnOk()
{
    hide();
}

==> sagua_0.2.3-1.tar.gz: sagua-0.2.3/src/aboutdlg.cc <==
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file aboutdlg.cc
/// @brief Class for 'About dialog' source file. 

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <libintl.h>

#include <gtkmm/box.h>
#include <gtkmm/stock.h>

#include "../include/aboutdlg.h"

AboutDlg::AboutDlg()
: logoImg_( PIXMAPSDIR "sagua-logo.png" )
{
    set_title( gettext("About") );
    set_resizable(false);
    set_border_width(12);

    const Glib::ustring aboutString = "<span weight=\"bold\" size=\"xx-large\">Sagua v" \
			PACKAGE_VERSION "</span>\n\nA Music Player for Gtk+/Gnome\n\n" \
			"<span size=\"small\">Copyright (c) 2004 HG, Rhee &lt;ez8tank@krpost.net&gt;" \
			"\nunder GNU GPL2</span>";
    infoLabel_.set_label(aboutString);
    infoLabel_.set_justify(Gtk::JUSTIFY_CENTER);
    infoLabel_.set_use_markup(true);
    
    Gtk::VBox* const mainBox = get_vbox();
    mainBox->set_spacing(6);
    mainBox->pack_start(logoImg_);
    mainBox->pack_start(infoLabel_); 

    Gtk::Button* const okBtn = add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);
    okBtn->signal_clicked().connect(
	sigc::mem_fun(*this, &AboutDlg::OnBtnOk) );

    show_all_children();
}

AboutDlg::~AboutDlg()
{
}

/// @brief Callback function when press OK button.
///
/// Callback function when press OK button. Just close dialog.
void AboutDlg::OnBtnOk()
{
    hide();
}
